@@ -31,32 +31,6 @@ from zope.traversing.interfaces import IContainmentRoot
 from zope.interface import directlyProvides
 
 
-def doctest_SectionJournalJSView():
-    """Tests for SectionJournalJSView.
-
-        >>> from schooltool.lyceum.journal.browser.journal import SectionJournalJSView
-        >>> view = SectionJournalJSView(object(), TestRequest())
-
-    Test the JavaScript elements provided by grading_events method.
-
-        >>> for event in view.grading_events():
-        ...     print '%4s %s' % (event['grade_value'], event['js_condition'])
-        'a'  event.which == 97 || event.which == 65
-        't'  event.which == 116 || event.which == 84
-        '1'  event.which == 49
-        '2'  event.which == 50
-        '3'  event.which == 51
-        '4'  event.which == 52
-        '5'  event.which == 53
-        '6'  event.which == 54
-        '7'  event.which == 55
-        '8'  event.which == 56
-        '9'  event.which == 57
-        '10' event.which == 48
-
-    """
-
-
 def doctest_JournalCalendarEventViewlet():
     """Tests for JournalCalendarEventViewlet.
 
@@ -383,6 +357,8 @@ def doctest_SectionTermAverageGradesColumn_getGrades():
         >>> class ScoreStub(object):
         ...     def __init__(self, value):
         ...         self.value = value
+        ...     def __repr__(self):
+        ...         return '<ScoreStub(%r)>' % self.value
         >>> MS = MeetingStub
         >>> SS = ScoreStub
         >>> dt = datetime
@@ -391,7 +367,7 @@ def doctest_SectionTermAverageGradesColumn_getGrades():
         ...                                     (MS(dt(2006, 1, 3, 10, 15)), SS(UNSCORED)),
         ...                                     (MS(dt(2006, 2, 1, 10, 15)), SS('3'))]
         >>> column.getGrades(item)
-        ['4']
+        [<ScoreStub('4')>]
 
     """
 
@@ -408,9 +384,18 @@ def doctest_SectionTermAverageGradesColumn_renderCell_renderHeader():
         >>> from schooltool.lyceum.journal.browser.journal import SectionTermAverageGradesColumn
         >>> class TermStub(object):
         ...     __name__ = "2006-Spring"
-        >>> column = SectionTermAverageGradesColumn("journal", TermStub())
+        >>> class ScoreSystemStub(object):
+        ...     getNumericalValue = lambda self, x: int(x)
+        >>> class ScoreStub(object):
+        ...     scoreSystem = ScoreSystemStub()
+        ...     def __init__(self, value):
+        ...         self.value = value
+        ...     def __repr__(self):
+        ...         return '<ScoreStub(%r)>' % self.value
+        >>> s = ScoreStub
 
-        >>> column.getGrades = lambda person: ["1", "2", "n"]
+        >>> column = SectionTermAverageGradesColumn("journal", TermStub())
+        >>> column.getGrades = lambda person: [s("1"), s("2")]
         >>> print_u(column.renderCell("john", "formatter"))
         1.500
 
@@ -428,13 +413,17 @@ def doctest_SectionTermAttendanceColumn_renderCell_renderHeader():
         >>> from schooltool.lyceum.journal.browser.journal import SectionTermAttendanceColumn
         >>> class TermStub(object):
         ...     __name__ = "2006-Spring"
+
+        >>> from schooltool.requirement.evaluation import Score
+        >>> from schooltool.lyceum.journal.journal import AbsenceScoreSystem
+        >>> s = lambda x: Score(AbsenceScoreSystem, x)
         >>> column = SectionTermAttendanceColumn("journal", TermStub())
 
-        >>> column.getAbsences = lambda person: ["1", "2", "n"]
+        >>> column.getAbsences = lambda person: [s("a")]
         >>> column.renderCell("john", "formatter")
         '1'
 
-        >>> column.getAbsences = lambda person: ["1", "n", "n", "N"]
+        >>> column.getAbsences = lambda person: [s("a"), s("a"), s("a")]
         >>> column.renderCell("john", "formatter")
         '3'
 
@@ -503,49 +492,6 @@ def doctest_StudentSelectionMixin():
     """
 
 
-def doctest_LyceumSectionJournalView_getLegendItems():
-    """Test for LyceumSectionJournalView.getLegendItems.
-
-        >>> from schooltool.lyceum.journal.browser.journal import LyceumSectionJournalView
-
-        >>> view = LyceumSectionJournalView(object(), TestRequest())
-
-    List grade values, shortcut keys and descriptions for the grades.
-
-        >>> for grade in view.getLegendItems():
-        ...     print '%3s %6s %s' % (grade['value'], grade['keys'],
-        ...                           grade['description'])
-        a   a, A Absent
-        t   t, T Tardy
-        1      1
-        2      2
-        3      3
-        4      4
-        5      5
-        6      6
-        7      7
-        8      8
-        9      9
-        10     0
-
-    """
-
-
-def doctest_LyceumSectionJournalView():
-    """
-    """
-
-
-def doctest_JournalAbsoluteURL():
-    """
-    """
-
-
-def doctest_JournalBreadcrumbs():
-    """
-    """
-
-
 def doctest_SectionListView():
     """Test for the SectionListView
 
